@@ -12,10 +12,7 @@
 // Qt
 #include <QWidget>
 
-class ContainedStringTableModel;
-
 class QPushButton;
-
 class QTreeView;
 class QSortFilterProxyModel;
 class QModelIndex;
@@ -24,6 +21,7 @@ class QSpinBox;
 namespace Kasten {
 
 class StringsExtractTool;
+class ContainedStringTableModel;
 
 class StringsExtractView : public QWidget
 {
@@ -50,9 +48,6 @@ private Q_SLOTS: // tool
     void onApplyableChanged(bool isApplyable);
     void onCanHighlightStringChanged(bool isSelectable);
 
-private Q_SLOTS:
-    void setFixedFontByGlobalSettings();
-
 private:
     StringsExtractTool* mTool;
 
